Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(716)

Unified Diff: third_party/WebKit/Source/modules/bluetooth/BluetoothError.h

Issue 2394423002: bluetooth: Rename blink::mojom::WebBluetoothError (Closed)
Patch Set: bluetooth: Rename blink::mojom::WebBluetoothError Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/bluetooth/BluetoothError.h
diff --git a/third_party/WebKit/Source/modules/bluetooth/BluetoothError.h b/third_party/WebKit/Source/modules/bluetooth/BluetoothError.h
index 6589963f5110a2f31cc2efaae63414ed1bd18671..311677d96a9fef7cf2ac76630f024f4a1c811cea 100644
--- a/third_party/WebKit/Source/modules/bluetooth/BluetoothError.h
+++ b/third_party/WebKit/Source/modules/bluetooth/BluetoothError.h
@@ -14,18 +14,18 @@ class DOMException;
class ScriptPromiseResolver;
// BluetoothError is used with CallbackPromiseAdapter to receive
// WebBluetoothError responses. See CallbackPromiseAdapter class comments.
class BluetoothError {
STATIC_ONLY(BluetoothError);
public:
// Interface required by CallbackPromiseAdapter:
using WebType =
- int32_t /* Corresponds to WebBluetoothError in web_bluetooth.mojom */;
+ int32_t /* Corresponds to WebBluetoothResult in web_bluetooth.mojom */;
static DOMException* take(
ScriptPromiseResolver*,
int32_t
- error /* Corresponds to WebBluetoothError in web_bluetooth.mojom */);
+ error /* Corresponds to WebBluetoothResult in web_bluetooth.mojom */);
};
} // namespace blink
« no previous file with comments | « content/renderer/bluetooth/web_bluetooth_impl.cc ('k') | third_party/WebKit/Source/modules/bluetooth/BluetoothError.cpp » ('j') | no next file with comments »
@@ -14,18 +14,18 @@ class DOMException;
class ScriptPromiseResolver;
// BluetoothError is used with CallbackPromiseAdapter to receive
-// WebBluetoothError responses. See CallbackPromiseAdapter class comments.
+// WebBluetoothResult responses. See CallbackPromiseAdapter class comments.
class BluetoothError {
STATIC_ONLY(BluetoothError);

Powered by Google App Engine
This is Rietveld 408576698